==> lime_python-2.0.2.tar.gz: lime_python-2.0.2/src/lime_python/protocol/network/transport.py <==
from abc import abstractmethod
from asyncio import Future
from typing import List

from ..listeners import EnvelopeListener


class Transport(EnvelopeListener):
    """Transport interface."""

    def __init__(self, compression: str, encryption: str) -> None:
        self.compression = compression
        self.encryption = encryption

    @abstractmethod
    def open_async(self, uri: str = None) -> Future:
        """Open a new connection.

        Args:
            uri (str): the server uri
        """
        pass

    @abstractmethod
    def close_async(self) -> Future:
        """Close a open connection."""
        pass

    @abstractmethod
    def send(self, envelope: dict) -> None:
        """Send a Envelope to the server.

        Args:
            envelope (dict): the serialized Envelope to be sent
        """
        pass

    @abstractmethod
    def get_supported_compression(self) -> List[str]:
        """Get supported compressions by the server.

        Returns:
            list[SessionCompression]: a list of supported Compressions
        """  # noqa: DAR202
        pass

    @abstractmethod
    def set_compression(self, compression: str) -> None:
        """Set a compression to use with the server.

        Args:
            compression (SessionCompression): the compression to be used
        """  # noqa: DAR103
        pass

    @abstractmethod
    def get_supported_encryption(self) -> List[str]:
        """Get supported encryptions by the server.

        Returns:
            list[SessionEncryption]: a list of supported Encryption
        """  # noqa: DAR202
        pass

    @abstractmethod
    def set_encryption(self, encryption: str) -> None:
        """Set a encryption to use with the server.

        Args:
            encryption (SessionEncryption): the encryption to be used
        """  # noqa: DAR103
        pass

==> lime_python-2.0.4.tar.gz: lime_python-2.0.4/src/lime_python/protocol/network/transport.py <==
from abc import abstractmethod
from typing import Awaitable, List

from ..listeners import EnvelopeListener


class Transport(EnvelopeListener):
    """Transport interface."""

    def __init__(self, compression: str, encryption: str) -> None:
        self.compression = compression
        self.encryption = encryption

    @abstractmethod
    async def open_async(self, uri: str = None) -> Awaitable:
        """Open a new connection.

        Args:
            uri (str): the server uri
        """
        pass

    @abstractmethod
    async def close_async(self) -> Awaitable:
        """Close a open connection."""
        pass

    @abstractmethod
    def send(self, envelope: dict) -> None:
        """Send a Envelope to the server.

        Args:
            envelope (dict): the serialized Envelope to be sent
        """
        pass

    @abstractmethod
    def get_supported_compression(self) -> List[str]:
        """Get supported compressions by the server.

        Returns:
            list[SessionCompression]: a list of supported Compressions
        """  # noqa: DAR202
        pass

    @abstractmethod
    def set_compression(self, compression: str) -> None:
        """Set a compression to use with the server.

        Args:
            compression (SessionCompression): the compression to be used
        """  # noqa: DAR103
        pass

    @abstractmethod
    def get_supported_encryption(self) -> List[str]:
        """Get supported encryptions by the server.

        Returns:
            list[SessionEncryption]: a list of supported Encryption
        """  # noqa: DAR202
        pass

    @abstractmethod
    def set_encryption(self, encryption: str) -> None:
        """Set a encryption to use with the server.

        Args:
            encryption (SessionEncryption): the encryption to be used
        """  # noqa: DAR103
        pass
